@@ -27,14 +27,12 @@ pkg_ref_cache.news.pkg_remote <- function(x, name, ...) {
     messages = "default")
 }
 
-
-
+#' @keywords internal
 pkg_ref_cache.news.pkg_install <- function(x, name, ...) {
   news_from_dir(system.file(package = x$name))
 }
 
-
-
+#' @keywords internal
 pkg_ref_cache.news.pkg_source <- function(x, name, ...) {
   news_from_dir(x$path)
 }
@@ -59,10 +57,11 @@ news_from_dir <- function(path) {
   # attempt to parse all news.* files
   for (i in seq_along(files)) {
     f <- files[[i]]
+    ext <- tools::file_ext(f)
     tryCatch({
       if (tolower(tools::file_ext(f)) == "rd") {
         content[[i]] <- .tools()$.news_reader_default(f)
-      } else if (tolower(tools::file_ext(f)) == "md"|| nchar(tools::file_ext(f)) == 0L) {
+      } else if (tolower(ext) == "md" || nchar(ext) == 0L) {
         # NOTE: should we do validation of markdown format?
         content[[i]] <- readLines(f, warn = FALSE)
       }
