@@ -164,7 +164,7 @@ pkg_source <- function(x) {
   name <- unname(desc[,"Package"])
 
   new_pkg_ref(name,
-              version = package_version(desc[,"Version"][[1]]),
+              version = desc[,"Version"][[1]],
               path = normalizePath(x),
               source = "pkg_source")
 }
@@ -242,7 +242,7 @@ as_pkg_ref <- function(x, ...) {
       pkg_ref_list[[i]] <- as_pkg_ref(x[[i]], source=source)
     }
 
-    return(vctrs::new_list_of(pkg_ref_list, ptype = pkg_ref(), class = "list_of_pkg_ref"))
+    return(vctrs::new_list_of(pkg_ref_list, ptype = list(), class = "list_of_pkg_ref"))
   } else {
     UseMethod("as_pkg_ref")
   }
